@@ -211,7 +211,7 @@ class Sink(Fragment):
 
         csum = m.hexdigest()
         # Inject last known value of destination path
-        path or OLD_CHECKSUMS.get(csum)
+        path = path or OLD_CHECKSUMS.get(csum)
         return csum, path
 
     def save(self):
